# ThonnyFlake8
A [Thonny](https://github.com/thonny/thonny) plugin to add [flake8](https://github.com/PyCQA/flake8) warnings.

## Installing
To install from pip3 using a terminal (or Powershell for Windows users)
```bash
pip3 install ThonnyFlake8
# Or
python3 -m pip install 
```

To install directly from Thonny:
1. Click "Tools" and then click "Manage Plug-ins..."
2. Search for "ThonnyFlake8" in the input box.
3. Click install.

After installing you will need to restart Thonny.
